import { useMemo } from 'react';
import moment from 'moment';
import { isValidDate } from '../utils/date';
export default function useRange(_ref) {
  let {
    startDate,
    endDate,
    numberOfMonths,
    firstMonthToRender
  } = _ref;
  return useMemo(() => {
    let start;
    const lastMonth = moment(firstMonthToRender).add(numberOfMonths, 'months').toDate();
    if (startDate && isValidDate(new Date(startDate))) {
      start = moment(startDate, 'YYYY-MM-DD').toDate();
      if (start > lastMonth) {
        start = undefined;
      }
    }
    let end = endDate && isValidDate(new Date(endDate)) && endDate <= lastMonth ? moment(endDate, 'YYYY-MM-DD').toDate() : undefined;
    return {
      start,
      end
    };
  }, [endDate, firstMonthToRender, numberOfMonths, startDate]);
}
//# sourceMappingURL=use-range.js.map